==> emma-spark-0.2.0-sources.jar: org/emmalanguage/api/spark/package.scala <==
/*
 * Copyright © 2014 TU Berlin (emma@dima.tu-berlin.de)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.emmalanguage
package api

import org.apache.spark.rdd.RDD
import org.apache.spark.sql.Dataset
import org.apache.spark.sql.SparkSession

package object spark {

  import Meta.Projections.ctagFor
  import SparkDataset.encoderForType

  implicit def fromDataset[A](
    implicit spark: SparkSession, m: Meta[A]
  ): Dataset[A] => DataBag[A] = new SparkDataset(_)

  implicit def toDataset[A](
    implicit spark: SparkSession, m: Meta[A]
  ): DataBag[A] => Dataset[A] = {
    case bag: SparkDataset[A] =>
      bag.rep
    case bag: SparkRDD[A] =>
      spark.createDataset(bag.rep)
    case bag: ScalaSeq[A] =>
      spark.createDataset(bag.rep)
    case bag =>
      throw new RuntimeException(s"Cannot convert a DataBag of type ${bag.getClass.getSimpleName} to a Spark Dataset")
  }

  implicit def fromRDD[A](
    implicit spark: SparkSession, m: Meta[A]
  ): RDD[A] => DataBag[A] = new SparkRDD(_)

  implicit def toRDD[A](
    implicit spark: SparkSession, m: Meta[A]
  ): DataBag[A] => RDD[A] = {
    case bag: SparkDataset[A] =>
      bag.rep.rdd
    case bag: SparkRDD[A] =>
      bag.rep
    case bag: ScalaSeq[A] =>
      spark.sparkContext.parallelize(bag.rep)
    case bag =>
      throw new RuntimeException(s"Cannot convert a DataBag of type ${bag.getClass.getSimpleName} to a Spark RDD")
  }

}

==> emma-spark-0.2.1-sources.jar: org/emmalanguage/api/spark/package.scala <==
/*
 * Copyright © 2014 TU Berlin (emma@dima.tu-berlin.de)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.emmalanguage
package api

import org.apache.spark.rdd.RDD
import org.apache.spark.sql.Dataset
import org.apache.spark.sql.Encoder
import org.apache.spark.sql.SparkSession
import org.apache.spark.sql.catalyst.encoders.ExpressionEncoder

package object spark {

  import Meta.Projections.ctagFor

  implicit def fromDataset[A](
    implicit spark: SparkSession, m: Meta[A]
  ): Dataset[A] => DataBag[A] = new SparkDataset(_)

  implicit def toDataset[A](
    implicit spark: SparkSession, m: Meta[A]
  ): DataBag[A] => Dataset[A] = {
    case bag: SparkDataset[A] =>
      bag.rep
    case bag: SparkRDD[A] =>
      spark.createDataset(bag.rep)
    case bag: ScalaSeq[A] =>
      spark.createDataset(bag.rep)
    case bag =>
      throw new RuntimeException(s"Cannot convert a DataBag of type ${bag.getClass.getSimpleName} to a Spark Dataset")
  }

  implicit def fromRDD[A](
    implicit spark: SparkSession, m: Meta[A]
  ): RDD[A] => DataBag[A] = new SparkRDD(_)

  implicit def toRDD[A](
    implicit spark: SparkSession, m: Meta[A]
  ): DataBag[A] => RDD[A] = {
    case bag: SparkDataset[A] =>
      bag.rep.rdd
    case bag: SparkRDD[A] =>
      bag.rep
    case bag: ScalaSeq[A] =>
      spark.sparkContext.parallelize(bag.rep)
    case bag =>
      throw new RuntimeException(s"Cannot convert a DataBag of type ${bag.getClass.getSimpleName} to a Spark RDD")
  }

  private[api] implicit def encoderForType[T: Meta]: Encoder[T] =
    ExpressionEncoder[T]
}
